@@ -18,9 +18,13 @@ from arnoldpaperboy.monitoring.custom_metrics import send_metric
 # the PassingLoggerAdapter class is based on the PassingLoggerAdapter class from
 # https://github.com/marrink-lab/vermouth-martinize/blob/master/vermouth/log_helpers.py
 # and is Copyright 2018 University of Groningen under the Apache 2.0 license.
+# The code here is basically a copy-paste from that, and mainly adapted to pass pylint.
 class PassingLoggerAdapter(LoggerAdapter):
-    """
-    Helper class that is actually capable of chaining multiple LoggerAdapters.
+    """Helper class that is actually capable of chaining multiple LoggerAdapters.
+
+    Args:
+        logger (logging.Logger): the logger to extend
+        extra (dict): the extra logging keywords
     """
     def __init__(self, logger, extra=None):
         if extra is None:
@@ -28,21 +32,37 @@ class PassingLoggerAdapter(LoggerAdapter):
         # These are all set by the logger.setter property. Which
         # super().__init__ calls.
         super().__init__(logger, extra)
-        # A LoggerAdapter does not have a manager, but logging.Logger.log needs
-        # it to see if logging is enabled.
 
+    # A LoggerAdapter does not have a manager, but logging.Logger.log needs
+    # it to see if logging is enabled.
     @property
     def manager(self):
-        """
-        .. autoattribute:: logging.Logger.manager
+        """proxy to the logger.manager
+
+        Returns:
+            logger.manager: the logger manager
         """
         return self.logger.manager
 
     @manager.setter
     def manager(self, new_value):
+        """Setter for the manager.
+
+        Args:
+            new_value (manager): replace the manager with this one
+        """
         self.logger.manager = new_value
 
     def process(self, msg, kwargs):
+        """logger.process method that does the right thing with 'extra'.
+
+        Args:
+            msg (string): message to log
+            kwargs (dict): kwargs to log
+
+        Returns:
+            tuple(str, dict): msg, kwargs
+        """
         # The documentation is a lie and the original implementation clobbers
         # 'extra' that is set by other LoggerAdapters in the chain.
         # LoggerAdapter's process method is FUBARed, and aliases kwargs and
@@ -61,6 +81,14 @@ class PassingLoggerAdapter(LoggerAdapter):
         return msg, kwargs
 
     def log(self, level, msg, *args, **kwargs):
+        """Log something. Pass on the right stuff to the internal logger.
+
+        Args:
+            level (logging.LEVEL): the logging level
+            msg (string): the message
+            *args (list): args
+            **kwargs (dict): kwargs
+        """
         # Differs from super().log because this calls `self.logger.log` instead
         # of self.logger._log. LoggerAdapters don't have a _log.
         if self.isEnabledFor(level):
@@ -74,68 +102,88 @@ class PassingLoggerAdapter(LoggerAdapter):
             else:
                 self.logger.log(level, msg, *args, **kwargs)
 
-    def addHandler(self, *args, **kwargs):
+    def addHandler(self, *args, **kwargs):  # pylint: disable=invalid-name
+        """Proxy for logger.addHandler
+
+        Args:
+            *args: args
+            **kwargs: kwargs
+        """
         self.logger.addHandler(*args, **kwargs)
 
-    def setLevel(self, *args, **kwargs):
+    def setLevel(self, *args, **kwargs):  # pylint: disable=arguments-differ
+        """Proxy for logger.setLevel
+
+        Args:
+            *args: args
+            **kwargs: kwargs
+        """
         self.logger.setLevel(*args, **kwargs)
 
 
 class AnnotatedLogger:
     """Contextmanager to temporary annotate the current global logger with extra kwargs.
 
-    Finds a logger by name in the call stack, and replaces it with a LoggerAdapter. On exit the
-    logger in the call stack will be reset again to it's original state. This enables the magic that
-    only the 'logger = logging.getLogger(__name__)' at the top of the file is necessary, and an
-    adapted logger can be used in other parts of the code without having to add code to either get
-    a new logger or to define logger as global.
+    Takes a logger or finds it by name in the call stack, and replaces it with a LoggerAdapter.
+    On exit the logger in the call stack will be reset again to it's original state. This enables
+    the magic that only the 'logger = logging.getLogger(__name__)' at the top of the file is
+    necessary, and an adapted logger can be used in other parts of the code without having to add
+    code to either get a new logger or to define logger as global.
 
     Args:
-        name (str): the (variable) name of the global logger to annotate
+        logger (str or logging.Logger): the (name of) the global logger to annotate
         kwargs (dict): the extra k:v pairs to attach to the logger
     """
 
-    def __init__(self, name, **kwargs):
-        self.name = name
+    def __init__(self, logger, **kwargs):
+        self.logger = logger
         self.kwargs = kwargs
         self.back = 0
-        self.logger_orig = None
+        self.from_frame = None
 
     def __enter__(self):
         """On entering the context.
 
-        Raises:
-            NameError: when the logger is not found.
-
         Returns:
             LoggerAdapter: the annotated logger
         """
-        frame = inspect.currentframe()
-        while self.name not in frame.f_globals:
-            frame = frame.f_back
-            self.back += 1
-            if frame is None:
-                raise NameError("Could not find logger named '{}'.".format(self.name))
-        self.logger_orig = frame.f_globals[self.name]
-        adapted_logger = PassingLoggerAdapter(self.logger_orig, self.kwargs)
-        frame.f_globals[self.name] = adapted_logger
-        del frame
+        frame = None
+        if isinstance(self.logger, str):
+            frame = inspect.currentframe()
+            while frame is not None and self.logger not in frame.f_globals:
+                frame = frame.f_back
+                self.back += 1
+            if frame is not None:
+                self.from_frame = self.logger
+                self.logger = frame.f_globals[self.logger]
+            else:
+                # could not find logger by name. Create a new one.
+                print("Warning: could not get logger by name. Creating new one.")
+                self.logger = logging.getLogger(__name__)
+
+        adapted_logger = PassingLoggerAdapter(self.logger, self.kwargs)
+
+        if self.from_frame:
+            frame.f_globals[self.from_frame] = adapted_logger
+            del frame
+
         return adapted_logger
 
     def __exit__(self, *_):
-        frame = inspect.currentframe()
-        while self.back > 0:
-            frame = frame.f_back
-            self.back -= 1
-        frame.f_globals[self.name] = self.logger_orig
-        del frame
+        if self.from_frame:
+            frame = inspect.currentframe()
+            while self.back > 0:
+                frame = frame.f_back
+                self.back -= 1
+            frame.f_globals[self.from_frame] = self.logger
+            del frame
 
 
 def autolog(logger_name='logger',
             level=logging.DEBUG,
             log_before=True,
             log_after=True,
-            metric=True,
+            metric=False,
             metric_name=None,
             metric_labels=None):
     """Decorate a function for logging candy.
@@ -183,8 +231,8 @@ def autolog(logger_name='logger',
             """The function wrapper.
 
             Args:
-                args (list): decorated function args
-                kwargs (dict): decorated function kwargs
+                *args (list): decorated function args
+                **kwargs (dict): decorated function kwargs
 
             Returns:
                 result: the result of the decorated function call
@@ -194,10 +242,10 @@ def autolog(logger_name='logger',
             func_sig = inspect.signature(function)
             bound_args = func_sig.bind(*args, **kwargs)
             bound_args.apply_defaults()
-            logger_extra = {'arg_{}'.format(k): v for k, v in bound_args.arguments.items()}
+            logger_extra = {f'arg_{k}': v for k, v in bound_args.arguments.items()}
             func_kwargs = logger_extra.pop('arg_kwargs', {})
             for key, value in func_kwargs.items():
-                logger_extra['arg_{}'.format(key)] = value
+                logger_extra[f'arg_{key}'] = value
 
             # override some of the logrecord attributes, otherwise these will become references to
             # this decorator instead of the decorated function when logging before and after.
@@ -210,7 +258,7 @@ def autolog(logger_name='logger',
                 pathname=func_file,
                 lineno=inspect.getsourcelines(function)[-1]
             )
-            overrides_prefixed = {'{}{}'.format(MAGIC_PREFIX, k): v for k, v in overrides.items()}
+            overrides_prefixed = {f'{MAGIC_PREFIX}{k}': v for k, v in overrides.items()}
 
             with AnnotatedLogger(logger_name, **logger_extra) as alogger:
 
@@ -240,7 +288,7 @@ def autolog(logger_name='logger',
                     )
             if metric:
                 custom_metric_name = (
-                    metric_name if metric_name else '{}.duration'.format(func_fullname)
+                    metric_name if metric_name else f'{func_fullname}.duration'
                 )
                 if metric_labels:
                     labels = {
@@ -260,7 +308,7 @@ def autolog(logger_name='logger',
                     if labels:
                         labels.update([labels_split.popitem()])
                         labels_split['truncated_args'] = ' '.join(
-                            ['{}: {};'.format(k, v) for k, v in labels.items()]
+                            [f'{k}: {v};' for k, v in labels.items()]
                         )
                 send_metric(
                     custom_metric_name,
