@@ -5,8 +5,8 @@
 import os
 import socket
 
-from google.cloud.logging._helpers import retrieve_metadata_server  # pylint: disable=protected-access
-from google.cloud.logging.resource import Resource as LoggingResource
+from google.cloud.logging_v2._helpers import retrieve_metadata_server  # pylint: disable=protected-access
+from google.cloud.logging_v2.resource import Resource as LoggingResource
 from google.cloud import monitoring_v3
 
 
@@ -25,6 +25,11 @@ MONITORING_CLIENT = monitoring_v3.MetricServiceClient()
 
 
 def labels_dict():
+    """Create dict with resource labels for k8s_container as required by stackdriver logging.
+
+    Returns:
+        dict: k8s_container resource labels
+    """
     return {
         'cluster_name': CLUSTER_NAME if CLUSTER_NAME else '',
         'project_id': PROJECT_ID if PROJECT_ID else '',
@@ -36,15 +41,31 @@ def labels_dict():
 
 
 def stringify_label(label):
-    # prettier printing for things like classes and functions
+    """Convert objects to stackdriver label-safe strings.
+
+    Prettier str repr for things like classes and functions. And limit labels to 1024 chars.
+
+    Args:
+        label (object): anything that should be displayed as label
+
+    Returns:
+        string: the stringified object
+    """
     label_str = (
-        '{}.{}'.format(label.__module__, label.__name__)
+        f'{label.__module__}.{label.__name__}'
         if hasattr(label, '__module__') and hasattr(label, '__name__')
         else str(label)
-    )
+    )[:1024]
     return label_str
 
-def logging_k8s_container():
+
+def logging_resource():
+    """Get the right stackdriver logging resource.
+
+    Returns:
+        LoggingResource: a k8s_container logging resource when in k8s, otherwise a global logging
+            resource.
+    """
     if PROJECT_ID and CLUSTER_NAME:
         return LoggingResource(
             type='k8s_container',
@@ -56,6 +77,12 @@ def logging_k8s_container():
     )
 
 def monitoring_resource():
+    """Get the right stackdriver monitoring resource.
+
+        Returns:
+            LoggingResource: a k8s_container logging resource when in k8s, otherwise a global
+                logging resource.
+        """
     if PROJECT_ID and CLUSTER_NAME:
         resource_type = 'k8s_container'
         labels = labels_dict()
